##  Step 3: Connect SAP LeanIX to the SAP Cloud ALM API
When you use SAP AI agent discovery, SAP LeanIX automatically uses the SAP Cloud ALM API to discover your SAP AI agents. This process is independent of your use of SAP Cloud ALM.
To connect SAP LeanIX to the SAP Cloud ALM API, do the following:
  1. In the administration area of SAP LeanIX, navigate to Integrations.
  2. Choose Add Integrations.
  3. Locate SAP AI Agents and choose Configure.
  4. Copy the service key from the SAP BTP cockpit that you created in step 2 and paste it under Enter Credentials.
  5. Choose Save.
